@@ -190,8 +190,7 @@ class TestIDCClient(unittest.TestCase):
             self.assertEqual(sum([len(files) for r, d, files in os.walk(temp_dir)]), 3)
 
     def test_download_dicom_instance(self):
-        i = IDCClient()
-        i.fetch_index("sm_instance_index")
+        self.client.fetch_index("sm_instance_index")
         with tempfile.TemporaryDirectory() as temp_dir:
             self.client.download_dicom_instance(
                 sopInstanceUID="1.3.6.1.4.1.5962.99.1.528744472.1087975700.1641206284312.14.0",
@@ -200,6 +199,26 @@ class TestIDCClient(unittest.TestCase):
 
             self.assertEqual(sum([len(files) for r, d, files in os.walk(temp_dir)]), 1)
 
+    def test_download_dicom_series_gcs(self):
+        with tempfile.TemporaryDirectory() as temp_dir:
+            self.client.download_dicom_series(
+                seriesInstanceUID="1.3.6.1.4.1.14519.5.2.1.7695.1700.153974929648969296590126728101",
+                downloadDir=temp_dir,
+                source_bucket_location="gcs",
+            )
+            self.assertEqual(sum([len(files) for r, d, files in os.walk(temp_dir)]), 3)
+
+    def test_download_dicom_instance_gcs(self):
+        self.client.fetch_index("sm_instance_index")
+        with tempfile.TemporaryDirectory() as temp_dir:
+            self.client.download_dicom_instance(
+                sopInstanceUID="1.3.6.1.4.1.5962.99.1.528744472.1087975700.1641206284312.14.0",
+                downloadDir=temp_dir,
+                source_bucket_location="gcs",
+            )
+
+            self.assertEqual(sum([len(files) for r, d, files in os.walk(temp_dir)]), 1)
+
     def test_download_with_template(self):
         dirTemplateValues = [
             None,
@@ -566,6 +585,24 @@ class TestIDCClient(unittest.TestCase):
         nlst_clinical = i.get_clinical_table("nlst_clinical")
         assert nlst_clinical is not None
 
+    def test_series_files_URLs(self):
+        c = IDCClient()
+        seriesInstanceUID = (
+            "1.3.6.1.4.1.14519.5.2.1.3671.4754.228015946741563785297552112143"
+        )
+        files_aws = c.get_series_file_URLs(seriesInstanceUID, "aws")
+        files_gcp = c.get_series_file_URLs(seriesInstanceUID, "gcp")
+        assert len(files_aws) > 0
+        assert len(files_gcp) == len(files_aws)
+
+    def test_instance_file_URLs(self):
+        c = IDCClient()
+        sopInstanceUID = "1.3.6.1.4.1.5962.99.1.1900325859.924065538.1719887277027.10.0"
+        file_url = "s3://idc-open-data/763fe058-7d25-4ba7-9b29-fd3d6c41dc4b/210f0529-c767-4795-9acf-bad2f4877427.dcm"
+        files_aws = c.get_instance_file_URL(sopInstanceUID, "aws")
+        files_gcp = c.get_instance_file_URL(sopInstanceUID, "gcp")
+        assert files_aws == files_gcp == file_url
+
 
 if __name__ == "__main__":
     unittest.main()
